#!/usr/bin/python

import urllib
import re
import datetime
import locale
import getopt
import sys

def fillStr(string, length, align):
	diff = 0
	filler = ""
	if(len(string) > length):
		return string
	else:
		diff = length - len(string)
		if(diff == 0):
			return string
	for i in range(diff):
			filler = filler + " "
	if(align == "left"):
		return string + filler
	elif(align == "right"):
		return filler + string
	else:
		filler_l = ""
		filler_r = ""
		for i in range(diff / 2):
			filler_l = filler_l + " "
			filler_r = filler_r + " "
		return filler_l + string + filler_r

def rmTblCellTag(string):
	res = re.sub(r"\s*<td>[\s]*", "", string)
	res = re.sub(r"\s*</td>[\s]*", "", res)
	return res

def rmTag(string, tag):
	res = re.sub(r"\s*<" + tag + ".*\">", "", string)
	res = re.sub(r"\s*</" + tag + ">[\s]*", "", res)	
	return res
			
def nbsp2str(string):
	return re.sub(r"&nbsp;", " ", string)

class Scoreboard():
		table = []
		matches = []
		row =	{
			"rank" : "",
			"team" : "",
			"matches" : "",
			"wins" : "",
			"draws" : "",
			"defeats" : "",
			"scored" : "",
			"conceded" : "",
			"diff" : "",
			"points" : ""
			}
		match =	{
			"weekday" : "",
			"datetime" : "",
			"team_home" : "",
			"team_away" : "",
			"result" : "",
			"status" : ""
			}
		updated = None
		expires = None
		profiles =	{
						"1.BL" : "http://www.kicker.de/news/fussball/bundesliga/spieltag/tabelle/",
						"2.BL" : "http://www.kicker.de/news/fussball/2bundesliga/spieltag/tabelle/",
						"ENG" : "http://www.kicker.de/news/fussball/intligen/england/tabelle/liga/",
						"ITA" : "http://www.kicker.de/news/fussball/intligen/italien/tabelle/liga/",
						"FRA" : "http://www.kicker.de/news/fussball/intligen/frankreich/tabelle/liga/",
						"AUT" : "http://www.kicker.de/news/fussball/intligen/oesterreich/tabelle/liga/",
						"SUI" : "http://www.kicker.de/news/fussball/intligen/schweiz/tabelle/liga/",
						"POR" : "http://www.kicker.de/news/fussball/intligen/portugal/tabelle/liga/",
						"POL" : "http://www.kicker.de/news/fussball/intligen/ligen/tabelle/liga/1710",
						"IRL" : "http://www.kicker.de/news/fussball/intligen/ligen/tabelle/liga/1921",
						"TUR" : "http://www.kicker.de/news/fussball/intligen/ligen/tabelle/liga/1707",
						"UEFA" : "http://www.kicker.de/news/fussball/uefa/spielrunde/runde/liga/"
						}
	
		def __init__(self, profile = "1.BL"):
			self.srcUrl = self.profiles[profile]
			locale.setlocale(locale.LC_ALL, '')

		def setUrl(self, url):
			self.srcUrl = url
			
		def getUrl(self):
			return self.srcUrl
			
		def setProfile(self, profile):
			if(profile in self.profiles.keys()):
				self.setUrl(self.profiles[profile])
				self.expires = None
				return True
			else:
				return False
		
		def getUpdated(self):
			return self.updated
		
		def getProfiles(self):
			return self.profiles
		
		def extractMatches(self, string):
			if not "iter" in dir(self.extractMatches):
				Scoreboard.__dict__['extractMatches'].iter = 0
			else:
				Scoreboard.__dict__['extractMatches'].iter += 1
				
			if(self.extractMatches.iter in [-2, -1, 3]):
				return 0
			
			keys = ["weekday", "datetime", "team_home", "", "team_away", "result", "status"]
			
			line = string.decode("iso-8859-1")
			res = rmTblCellTag(line)
			
			if(self.extractMatches.iter == 0):
				self.matches.append(self.match.copy())
			elif(self.extractMatches.iter in [1, 5]):
				res = rmTag(res, "font")
				res = nbsp2str(res)
			elif(self.extractMatches.iter in [2, 4]):
				res = rmTag(res, "a")
				res = nbsp2str(res)
			elif(self.extractMatches.iter == 6):
				res = rmTag(res, "a")
				res = nbsp2str(res)
				if(not res == "Live"):
					res = ""
			elif(self.extractMatches.iter == 7):
				Scoreboard.__dict__['extractMatches'].iter = -2
				return 0
				
			self.matches[len(self.matches)-1][keys[self.extractMatches.iter]] = res
		
		
		def extractInfo(self, string):
			if not "iter" in dir(self.extractInfo):
				Scoreboard.__dict__['extractInfo'].iter = 0
			else:
				Scoreboard.__dict__['extractInfo'].iter += 1
				
			if(self.extractInfo.iter in [2, 4, 8, 12]):
				return 0
				
			keys = ["rank", "team", "", "matches", "", "wins", "draws", "defeats", "", "scored", "conceded", "diff", "", "points"]
				
			line = string.decode("iso-8859-1")
			res = rmTblCellTag(line)
				
			if(self.extractInfo.iter == 0):
				self.table.append(self.row.copy())
			elif(self.extractInfo.iter == 1):
				res = re.sub(r"\s*<a.*\">", "", res)
				res = re.sub(r"\s*</a>[\s]*", "", res)
				res = re.sub(r"&nbsp;", " ", res)
			elif(self.extractInfo.iter == 9):
				goals = re.split(r"[\s]*:[\s]*", res)
				scored = goals[0]
				conceded = goals[1]
				self.table[(len(self.table)-1)][keys[self.extractInfo.iter]] = scored
				Scoreboard.__dict__['extractInfo'].iter += 1
				res = conceded
			elif(self.extractInfo.iter == 13):
				Scoreboard.__dict__['extractInfo'].iter = -1
			
			self.table[len(self.table)-1][keys[self.extractInfo.iter]] = res
		
		def getMatches(self):
			self.getPage("Matches")
			return self.matches
		
		def getTable(self):
			self.getPage("Table")
			return self.table
		
		def getAll(self):
			self.getPage()
			sb = [self.updated, self.matches, self.table]
			return sb
		
		def printMatches(self):
			self.getPage()
			print self.updated
			print
			for row in self.matches:
				line  = fillStr(row["weekday"], 3, "left")
				line += fillStr(row["datetime"], 15, "left")
				line += fillStr(row["team_home"], 30, "left")
				line += fillStr(":", 3, "center")
				line += fillStr(row["team_away"], 30, "left")
				line += fillStr(row["result"], 11, "left")
				line += fillStr(row["status"], 5, "left")
				print line
		
		def printTable(self):
			self.getPage()
#				print self.updated
			for row in self.table:
				line  = fillStr(row["rank"] + ". ", 4, "right")
				line += fillStr(row["team"], 30, "left")
				line += fillStr(row["matches"] + " ", 4, "right")
				line += fillStr(row["wins"] + " ", 3, "right")
				line += fillStr(row["draws"] + " ", 3, "right")
				line += fillStr(row["defeats"] + " ", 3, "right")
				line += fillStr(row["scored"], 4, "right")
				line += ":"
				line += fillStr(row["conceded"], 3, "right")
				line += fillStr(row["diff"], 5, "right")
				line += fillStr(row["points"], 4, "right")
				print(line)
		
			
		def getPage(self, els = ["Matches", "Table"]):
			if("Matches" in els):
				grabMatches = True
			else:
				grabMatches = False
			if("Table" in els):
				grabTable = True
			else:
				grabTable = False
				
			doMatches = False
			doTable = False
			skip = True
			whitelist = []
			whitelist.append(r"\A\s*<td")
			startline = r"\s*<h3 class=\"tabhead600\">Tabelle</h3>[\s]*"
			endline = r"\s*</table>[\s]*"
			start_matches = r"\s*<span style=\"float:left;\">Begegnungen</span>\s*"
			end_matches = r"\s*<!-- ad-tag Position1 -->\s*"
			
			try:
				src = urllib.urlopen(self.srcUrl)
				header = src.info()
				locale.setlocale(locale.LC_TIME, 'C')
				self.updated = datetime.datetime.strptime(header["date"], "%a, %d %b %Y %H:%M:%S GMT")
				locale.setlocale(locale.LC_TIME, '')
				self.updated = self.updated.strftime("%A, %d. %b %Y %H:%M") + " GMT"
				#if(self.expires != None):
					#if(header["expires"] == self.expires):
						#self.expires = header["expires"]
						#return True
				if(len(self.table) != 0):
					del self.table[0:(len(self.table))]
				if(len(self.matches) != 0):
					del self.matches[0:(len(self.matches))]
				else:
					self.expires = header["expires"]
					
			except:
				print "Fehler: Adresse ", self.srcUrl, " kann nicht erreicht werden"
				sys.exit()
			for line in src:
				#entered section?
				if(grabMatches and not doMatches and re.search(start_matches, line)):
					doMatches = True
				elif(grabTable and not doTable and re.search(startline, line)):
					doTable = True
				#left  Section?
				if(doMatches and re.search(end_matches, line)):
					doMatches = False
				elif(doTable and re.search(endline, line)):
					doTable = False
				#is there a element to grab?
				if(doMatches):
					for wld in whitelist:
						if(re.search(wld, line)):
							skip = False
				elif(doTable):
					for wld in whitelist:
						if(re.search(wld, line)):
							skip = False
				#result
				if(doMatches and not skip):
					self.extractMatches(line)
				elif(doTable and not skip):
					self.extractInfo(line)
				skip = True
				
			#self.updated = datetime.datetime.now().strftime("%A, %d. %b %Y %H:%M")
		#end of getTable
	
def main():
	try:
		opts, args = getopt.getopt(sys.argv[1:], "vp:u:", ["version", "profile=", "url="])
	except:
		pass
	
	customUrl = None
	shutdown = False
	
	try:
		i = 0
		for o, a in opts:
			if(o in ["-v", "--version"]):
				print "Program with no name, Version 0.1"
				shutdown = True
			
			if(o in ["-u", "--url"]):
				customUrl = a
				
			if(o in ["-p", "--profile"]):
				liga = Scoreboard(a)
	except:
		pass
	finally:
		if(shutdown):
			sys.exit()
			
	try:
		if(liga):
			pass
	except:
		liga = Scoreboard()
		if(not customUrl == None):
			liga.setUrl(customUrl)
		
	liga.printMatches()
	print
	liga.printTable()
	
if __name__ == "__main__":
	main()
