#!/usr/bin/python
# -*- coding: utf-8 -*-

import scoreboard
import sys
from PyQt4 import QtGui, QtCore
from main import Ui_MainWindow as MainDlg

class Skoreboard(QtGui.QMainWindow, MainDlg):
	title = "Skoreboard"
	tabs = ["Über&sicht", "&Tabelle"]
	gbs = [["Spiele", "Quicktabelle"],
		   ["Tabelle"]]
	buttons = ["&Aktualisieren"]
	tableCaps = [["Rang", "Mannschaft", "Spiele", "G", "U", "V", "Tore", "Diff.", "Punkte"],
				 ["Heim", "Resultat", "Auswärts"],
				 ["Rang", "Mannschaft", "Diff.", "Punkte"]
				]
	brushes = {"Live" : None}
	profiles = None
	
	def __init__(self):
		QtGui.QDialog.__init__(self)
		self.setupUi(self)
		self.connect(self.pbRefresh, QtCore.SIGNAL("clicked()"), self.onRefreshBtn)
		self.connect(self.sbTabs, QtCore.SIGNAL("currentChanged(int)"), self.onRefreshBtn)
		self.connect(self.cbProfile, QtCore.SIGNAL("currentIndexChanged(int)"), self.onProfileChng)
		
	def init(self):
		self.scbd = scoreboard.Scoreboard()
		self.twTable.setColumnCount(len(self.tableCaps[0]))
		self.twMatches.setColumnCount(len(self.tableCaps[1]))
		self.twShortTable.setColumnCount(len(self.tableCaps[2]))
		self.assignCaptions()
		
		self.profiles = self.scbd.getProfiles().items()
		self.profiles.sort()
		for name, url in self.profiles:
			self.cbProfile.addItem(name)
			
		self.brushes["Live"] = QtGui.QBrush(QtGui.QColor(255, 255, 96))
			
		self.scbd.setProfile(self.profiles[0][0])
		self.cbProfile.currentIndex = 0
			
	def assignCaptions(self):
		self.setWindowTitle(self.title)
		i = 0
		for s in self.tabs:
			self.sbTabs.setTabText(i, s)
			i += 1
		self.gbShortTable.setTitle(self.gbs[0][1])
		self.gbMatches.setTitle(self.gbs[0][0])
		self.gbTable.setTitle(self.gbs[1][0])
		self.pbRefresh.setText(self.buttons[0])
		i = 0
		for cap in self.tableCaps[0]:
			item = QtGui.QTableWidgetItem(cap)
			self.twTable.setHorizontalHeaderItem(i, item)
			i += 1
		i = 0
		for cap in self.tableCaps[1]:
			item = QtGui.QTableWidgetItem(cap)
			self.twMatches.setHorizontalHeaderItem(i, item)
			i += 1
		i = 0
		for cap in self.tableCaps[2]:
			item = QtGui.QTableWidgetItem(cap)
			self.twShortTable.setHorizontalHeaderItem(i, item)
			i += 1
		
	def refreshMatches(self):
		self.twMatches.clearContents()
		matches = self.scbd.getMatches()
		self.twMatches.setRowCount(len(matches))
		for i in range(self.twMatches.rowCount()):
			self.twMatches.setVerticalHeaderItem(i, QtGui.QTableWidgetItem(""))
		keys = ["team_home", "result", "team_away"]
		x = 0
		y = 0
		date = False
		for row in matches:
			for x in range(len(self.tableCaps[1])):
				if(((row["weekday"] != "") or (row["datetime"] != "")) and not date):
					item = QtGui.QTableWidgetItem(row["weekday"] + ", " + row["datetime"])
					self.twMatches.setItem(y, x, item)
					self.twMatches.setRowCount(self.twMatches.rowCount()+1)
					self.twMatches.setVerticalHeaderItem(self.twMatches.rowCount()-1, QtGui.QTableWidgetItem(""))
					date = True
					y += 1
				item = QtGui.QTableWidgetItem(row[keys[x]])
				if(row["status"] == "Live"):
					item.setBackground(self.brushes["Live"])
				self.twMatches.setItem(y, x, item)
			y += 1
			date = False
		
	def refreshTable(self, quick = False):
		if(quick):
			qtTable = self.twShortTable
			keys = ["rank", "team", "diff", "points"]
			tci = 2
		else:
			qtTable = self.twTable
			keys = ["rank", "team", "matches", "wins", "draws", "defeats", "scored", "diff", "points"]
			tci = 0
		
		qtTable.clearContents()
		table = self.scbd.getTable()
		qtTable.setRowCount(len(table))
		for i in range(qtTable.rowCount()):
			qtTable.setVerticalHeaderItem(i, QtGui.QTableWidgetItem(""))
		
		x = 0
		y = 0
		for row in table:
			for x in range(len(self.tableCaps[tci])):
				if(x != 6):
					item = QtGui.QTableWidgetItem(row[keys[x]])
					if(x != 1):
						item.setTextAlignment(2)
				else:
					s = row[keys[x]] + ":" + row["conceded"]
					item = QtGui.QTableWidgetItem(s)
					item.setTextAlignment(4)
				
				qtTable.setItem(y, x, item)
			y += 1
	
	def onProfileChng(self, index):
		self.scbd.setProfile(self.profiles[index][0])
		self.onRefreshBtn()
		
	def onRefreshBtn(self):
		if(self.sbTabs.currentIndex() == 0):
			self.refreshMatches()
			self.refreshTable(True)
		elif(self.sbTabs.currentIndex() == 1):
			self.refreshTable()

app = QtGui.QApplication(sys.argv)

skbd = Skoreboard()
skbd.init()
skbd.show()
sys.exit(app.exec_())